Index: lib/matplotlib/backend_bases.py
===================================================================
--- lib/matplotlib/backend_bases.py	(revision 8106)
+++ lib/matplotlib/backend_bases.py	(working copy)
@@ -1858,34 +1858,53 @@
         #    self.destroy() # how cruel to have to destroy oneself!
         #    return
 
-        if event.key == 'f':
+        # Load key-mappings from your matplotlibrc file.
+        f = rcParams['fullscreen']
+        home_keys = rcParams['home']
+        back_keys = rcParams['back']
+        forward_keys = rcParams['forward']
+        p = rcParams['pan']
+        z = rcParams['zoom']
+        save_keys = rcParams['save']
+        grid_keys = rcParams['grid']
+        toggle_yscale_keys = rcParams['yscale']
+        toggle_xscale_keys = rcParams['xscale']
+        all = rcParams['all_axes']
+
+        # to get a common standard we move all keys for each action into a list
+        for key in [f, home_keys, back_keys, forward_keys, p, z, save_keys,
+                    grid_keys, toggle_xscale_keys, toggle_yscale_keys, all]:
+            if type(key) is not list:
+                key = list(key)
+        
+        if event.key in f:
             self.full_screen_toggle()
 
         # *h*ome or *r*eset mnemonic
-        elif event.key == 'h' or event.key == 'r' or event.key == "home":
+        elif event.key in home_keys:
             self.canvas.toolbar.home()
         # c and v to enable left handed quick navigation
-        elif event.key == 'left' or event.key == 'c' or event.key == 'backspace':
+        elif event.key in back_keys:
             self.canvas.toolbar.back()
-        elif event.key == 'right' or event.key == 'v':
+        elif event.key in forward_keys:
             self.canvas.toolbar.forward()
         # *p*an mnemonic
-        elif event.key == 'p':
+        elif event.key in p:
             self.canvas.toolbar.pan()
         # z*o*om mnemonic
-        elif event.key == 'o':
+        elif event.key in z:
             self.canvas.toolbar.zoom()
-        elif event.key == 's':
+        elif event.key in save_keys:
             self.canvas.toolbar.save_figure(self.canvas.toolbar)
 
         if event.inaxes is None:
             return
 
         # the mouse has to be over an axes to trigger these
-        if event.key == 'g':
+        if event.key in grid_keys:
             event.inaxes.grid()
             self.canvas.draw()
-        elif event.key == 'l':
+        elif event.key in toggle_yscale_keys:
             ax = event.inaxes
             scale = ax.get_yscale()
             if scale=='log':
@@ -1894,14 +1913,24 @@
             elif scale=='linear':
                 ax.set_yscale('log')
                 ax.figure.canvas.draw()
+        elif event.key in toggle_xscale_keys:
+            ax = event.inaxes
+            scalex = ax.get_xscale()
+            if scalex=='log':
+                ax.set_xscale('linear')
+                ax.figure.canvas.draw()
+            elif scalex=='linear':
+                ax.set_xscale('log')
+                ax.figure.canvas.draw()
 
-        elif event.key is not None and (event.key.isdigit() and event.key!='0') or event.key=='a':
-            # 'a' enables all axes
-            if event.key!='a':
-                n=int(event.key)-1
+        elif event.key is not None and (event.key.isdigit() and event.key!='0')\
+        or event.key in all:
+            # keys in 'all' enables all axes
+            if not (event.key in all):
+                n = int(event.key)-1
             for i, a in enumerate(self.canvas.figure.get_axes()):
                 if event.x is not None and event.y is not None and a.in_axes(event):
-                    if event.key=='a':
+                    if event.key in all:
                         a.set_navigate(True)
                     else:
                         a.set_navigate(i==n)
